==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/opsworks/kotlin/inputs/StackCustomCookbooksSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opsworks.kotlin.inputs

import com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property password Password to use when authenticating to the source. The provider cannot perform drift detection of this configuration.
 * @property revision For sources that are version-aware, the revision to use.
 * @property sshKey SSH key to use when authenticating to the source. This provider cannot perform drift detection of this configuration.
 * @property type The type of source to use. For example, "archive".
 * @property url The URL where the cookbooks resource can be found.
 * @property username Username to use when authenticating to the source.
 */
public data class StackCustomCookbooksSourceArgs(
    public val password: Output<String>? = null,
    public val revision: Output<String>? = null,
    public val sshKey: Output<String>? = null,
    public val type: Output<String>,
    public val url: Output<String>,
    public val username: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs> {
    override fun toJava(): com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs =
        com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs.builder()
            .password(password?.applyValue({ args0 -> args0 }))
            .revision(revision?.applyValue({ args0 -> args0 }))
            .sshKey(sshKey?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 }))
            .url(url.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StackCustomCookbooksSourceArgs].
 */
@PulumiTagMarker
public class StackCustomCookbooksSourceArgsBuilder internal constructor() {
    private var password: Output<String>? = null

    private var revision: Output<String>? = null

    private var sshKey: Output<String>? = null

    private var type: Output<String>? = null

    private var url: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value Password to use when authenticating to the source. The provider cannot perform drift detection of this configuration.
     */
    @JvmName("rfhksqrshqnardtw")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value For sources that are version-aware, the revision to use.
     */
    @JvmName("cfuncbkmpkhythha")
    public suspend fun revision(`value`: Output<String>) {
        this.revision = value
    }

    /**
     * @param value SSH key to use when authenticating to the source. This provider cannot perform drift detection of this configuration.
     */
    @JvmName("xvuvtdlaxcrqnbds")
    public suspend fun sshKey(`value`: Output<String>) {
        this.sshKey = value
    }

    /**
     * @param value The type of source to use. For example, "archive".
     */
    @JvmName("flxtyewtbuguvfgj")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The URL where the cookbooks resource can be found.
     */
    @JvmName("wxsxftsxvsqiixvp")
    public suspend fun url(`value`: Output<String>) {
        this.url = value
    }

    /**
     * @param value Username to use when authenticating to the source.
     */
    @JvmName("jefstwfcukgqjarw")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value Password to use when authenticating to the source. The provider cannot perform drift detection of this configuration.
     */
    @JvmName("ioxpftqfscrmjipw")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value For sources that are version-aware, the revision to use.
     */
    @JvmName("wowocquagcnblttn")
    public suspend fun revision(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.revision = mapped
    }

    /**
     * @param value SSH key to use when authenticating to the source. This provider cannot perform drift detection of this configuration.
     */
    @JvmName("kyukgewgenflrwpm")
    public suspend fun sshKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sshKey = mapped
    }

    /**
     * @param value The type of source to use. For example, "archive".
     */
    @JvmName("bqsdyqdmojvewuwi")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The URL where the cookbooks resource can be found.
     */
    @JvmName("biaqbiooagbybmds")
    public suspend fun url(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.url = mapped
    }

    /**
     * @param value Username to use when authenticating to the source.
     */
    @JvmName("qghhfddrvdvvvxbk")
    public suspend fun username(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): StackCustomCookbooksSourceArgs = StackCustomCookbooksSourceArgs(
        password = password,
        revision = revision,
        sshKey = sshKey,
        type = type ?: throw PulumiNullFieldException("type"),
        url = url ?: throw PulumiNullFieldException("url"),
        username = username,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/opsworks/kotlin/inputs/StackCustomCookbooksSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opsworks.kotlin.inputs

import com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property password Password to use when authenticating to the source. The provider cannot perform drift detection of this configuration.
 * @property revision For sources that are version-aware, the revision to use.
 * @property sshKey SSH key to use when authenticating to the source. This provider cannot perform drift detection of this configuration.
 * @property type The type of source to use. For example, "archive".
 * @property url The URL where the cookbooks resource can be found.
 * @property username Username to use when authenticating to the source.
 */
public data class StackCustomCookbooksSourceArgs(
    public val password: Output<String>? = null,
    public val revision: Output<String>? = null,
    public val sshKey: Output<String>? = null,
    public val type: Output<String>,
    public val url: Output<String>,
    public val username: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs> {
    override fun toJava(): com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs =
        com.pulumi.aws.opsworks.inputs.StackCustomCookbooksSourceArgs.builder()
            .password(password?.applyValue({ args0 -> args0 }))
            .revision(revision?.applyValue({ args0 -> args0 }))
            .sshKey(sshKey?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 }))
            .url(url.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StackCustomCookbooksSourceArgs].
 */
@PulumiTagMarker
public class StackCustomCookbooksSourceArgsBuilder internal constructor() {
    private var password: Output<String>? = null

    private var revision: Output<String>? = null

    private var sshKey: Output<String>? = null

    private var type: Output<String>? = null

    private var url: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value Password to use when authenticating to the source. The provider cannot perform drift detection of this configuration.
     */
    @JvmName("fprvmalksguhqbwv")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value For sources that are version-aware, the revision to use.
     */
    @JvmName("whlgmrxbmulpnkkq")
    public suspend fun revision(`value`: Output<String>) {
        this.revision = value
    }

    /**
     * @param value SSH key to use when authenticating to the source. This provider cannot perform drift detection of this configuration.
     */
    @JvmName("cwxkhhetmcltunxl")
    public suspend fun sshKey(`value`: Output<String>) {
        this.sshKey = value
    }

    /**
     * @param value The type of source to use. For example, "archive".
     */
    @JvmName("gkydmvcldbwqfgqq")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The URL where the cookbooks resource can be found.
     */
    @JvmName("ywlkaindjmeqrwvm")
    public suspend fun url(`value`: Output<String>) {
        this.url = value
    }

    /**
     * @param value Username to use when authenticating to the source.
     */
    @JvmName("ejvfrryjfrsyrvmc")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value Password to use when authenticating to the source. The provider cannot perform drift detection of this configuration.
     */
    @JvmName("dsrwycycbbsejdej")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value For sources that are version-aware, the revision to use.
     */
    @JvmName("niaggwiirjjqfbob")
    public suspend fun revision(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.revision = mapped
    }

    /**
     * @param value SSH key to use when authenticating to the source. This provider cannot perform drift detection of this configuration.
     */
    @JvmName("kypektlbklniayyx")
    public suspend fun sshKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sshKey = mapped
    }

    /**
     * @param value The type of source to use. For example, "archive".
     */
    @JvmName("bpytptlrnuqqifqt")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The URL where the cookbooks resource can be found.
     */
    @JvmName("qwgwofoieqqplyoc")
    public suspend fun url(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.url = mapped
    }

    /**
     * @param value Username to use when authenticating to the source.
     */
    @JvmName("byhggigsohxmhcco")
    public suspend fun username(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): StackCustomCookbooksSourceArgs = StackCustomCookbooksSourceArgs(
        password = password,
        revision = revision,
        sshKey = sshKey,
        type = type ?: throw PulumiNullFieldException("type"),
        url = url ?: throw PulumiNullFieldException("url"),
        username = username,
    )
}
